@@ -6,7 +6,7 @@ hmap<-function(x,dominance=FALSE,...)
   trace <- NULL
 #  if(!is.matrix(x))     stop("first argument should be a matrix")
   if(is.matrix(x)) x <- .5*(x-t(x))
-  if(is(x,"decomposition")) x <-x$A
+  if(is(x,"skewsymmetry")) x <-x$A
 
   if (nrow(x)!=ncol(x)) stop("the same number of rows and columns are expected")
   #  order//
